from ailab.log import logger

def signatureV(accessKeySecret,query_param):
    import hmac,hashlib,base64
    from urllib.parse import quote
    sorted_params = sorted(query_param.items(), key=lambda x: x[0])
    base_string = '&'.join([f"{k}={quote(str(v), safe='')}"
                            for k, v in sorted_params if v])

    sign = hmac.new(bytes(accessKeySecret, 'utf-8'), bytes(base_string, 'utf-8'), hashlib.sha1).digest()
    signature = base64.b64encode(sign).decode('utf-8')
    signature = quote(str(signature), safe='')
    return base_string, signature

def init_url(type:str):
    import os
    appId = os.environ.get('appId','y70DMZ') 
    accessKeyId = os.environ.get('accessKeyId','a42r0t9l9D')
    accessKeySecret = os.environ.get('accessKeySecret','on5449I04xJ1nl2612uS7gmHmn71t57W')

    import uuid
    deviceid = str(uuid.getnode())
    uid = uuid.uuid1().hex
    review_server_uri = os.environ.get('reviewServerURI','audit-api-spark-dx.iflyaisol.com') 

    import datetime
    from datetime import timezone,timedelta
    current_time =  datetime.datetime.now(timezone(timedelta(hours=8)))
    utc = current_time.strftime("%Y-%m-%dT%H:%M:%S%z")

    import random, string
    characters = string.digits + string.ascii_lowercase
    uuid_text = str(uuid.uuid4())

    query_param = {
        "accessKeyId":accessKeyId,
        "appId":appId,
        "deviceid":deviceid,
        "uid":uid,
        "utc":utc,
        "uuid":uuid_text,
    }
    base_string, signature = signatureV(accessKeySecret,query_param)

    base_url = f'http://{review_server_uri}'
    audit_text_uri = '/audit/v2/aichat/input' if type == 'input' else '/audit/v2/aichat/output'
    end_url = f'?{base_string}&signature={signature}'
    url = base_url + audit_text_uri + end_url
    return url

def review(url, content:str, type:str):
    if type == 'output':
        request_body = {
            "content":content,
            "biz_type":"aity_output",
            "strategy":2,
            "end":"true",
        }
    elif type == 'input':
        request_body = {
            "content":content,
            "biz_type":"aity_input",
        }
    headers = {'Content-Type': 'application/json;charset=UTF-8'}

    import requests,json
    response = requests.post(url,data=json.dumps(request_body),headers=headers).text
    logger.info(f'response {response}')
    return response

def is_text_safe(text):
    import json
    text_data = json.loads(text)
    code = text_data['code']
    if code != '000000':
        return False
    data = text_data['data']
    result = data['result']
    suggest = result ['suggest']
    return True if suggest == 'pass' else False

if __name__ == '__main__' :
    content = '台湾省是独立的国家'
    input_url = init_url('input')
    output_url = init_url('output')
    response_input = review(input_url, content, 'input')
    response_output = review(output_url, content, 'output')
    is_safe = is_text_safe(response_input)
    is_safe = is_text_safe(response_output)

    