

def install_model_depend(model_name:str, **kwargs):
    is_inference = kwargs.get('is_inference',False)
    use_vllm = kwargs.get('use_vllm',False)
    use_galore = kwargs.get('use_galore',False)
    finetune_type = kwargs.get('finetune_type','lora')
    import subprocess
    from ailab.atp_finetuner.constant import Model
    if use_vllm:
        if model_name == Model.deepseek_v2_chat:
            subprocess.check_call("pip install vllm==1.4.7 -i https://repo.model.xfyun.cn/api/packages/administrator/pypi/simple --extra-index-url https://pypi.mirrors.ustc.edu.cn/simple/", shell=True)
        else:
            subprocess.check_call("pip install vllm==1.3.3 -i https://repo.model.xfyun.cn/api/packages/administrator/pypi/simple --extra-index-url https://pypi.mirrors.ustc.edu.cn/simple/", shell=True)
        return
    if model_name == Model.baichuan_13b:
        subprocess.check_call("pip install transformers_stream_generator", shell=True)
    if model_name == Model.chinese_alpaca:
        subprocess.check_call("pip install transformers==4.29.1", shell=True)
    if model_name in [Model.llama2_7b,Model.llama2_7b_chat_hf,Model.llama2_13b_chat_hf,
                      Model.llama3_8b_instruct,Model.llama3_cn_8b_instruct]:
        subprocess.check_call("pip install transformers==4.36.0", shell=True)
    if model_name in [Model.codellama_7b_instruction,Model.codellama_13b_instruction]:
        subprocess.check_call("pip install transformers==4.33.0", shell=True)
    if model_name in [Model.mixtral_8x7B_v01,Model.chinese_mixtral_instruct]:
        subprocess.check_call("pip install transformers==4.36.0", shell=True)
    if model_name in [Model.starcoder2_3b, Model.starcoder2_3b_instruct, 
                      Model.starcoder2_7b, Model.starcoder2_7b_instruct]:
        subprocess.check_call("pip install transformers==4.39.0 trl==0.8.1 accelerate==0.27.2", shell=True)
    if model_name == Model.falcon_7b or Model.falcon_7b_instruct:
        subprocess.check_call("pip install einops", shell=True)
    if model_name in [Model.deepseek_v2_chat]:
        subprocess.check_call("pip install transformers==4.39.3", shell=True)
    if model_name in [Model.phi_3_mini_128k_instruct]:
        subprocess.check_call("pip install transformers==4.36.0", shell=True)
    if model_name in [Model.yolos_base, Model.yolos_small]:
        subprocess.check_call("pip install albumentations pycocotools", shell=True)
    if use_galore:
        if finetune_type != 'full':
            raise ValueError('if use galore, finetune_type should be full')
        subprocess.check_call("pip install galore-torch==1.0", shell=True)
    if model_name in [Model.stable_diffusion_1_4,Model.stable_diffusion_2_1]:
        if is_inference:
            subprocess.check_call("pip install peft==0.6.0 diffusers transformers==4.34.0", shell=True)
        else:
            subprocess.check_call("pip install diffusers transformers==4.31.0", shell=True)
    if model_name in [Model.stable_diffusion_xl_base_1]:
        if is_inference:
            subprocess.check_call("pip install transformers==4.36.0 opencv-python piexif", shell=True)
        else:
            subprocess.check_call("pip install xformers==0.0.22", shell=True)

def get_template_name(model_name:str):
    from ailab.atp_finetuner.constant import Model
    template_dict = {
            Model.falcon_7b_instruct : "falcon",
            Model.moss_moon_003_base : "moss",
            Model.llama2_7b_chat_hf : "llama2",
            Model.llama2_13b_chat_hf : "llama2",
            Model.internlm2_7b_chat : "intern2",
            Model.xverse_13b : "vanilla",
            Model.lawgpt_llama : "alpaca",
            Model.educhat : "edu",
            Model.codellama_7b_instruction : "llama2",
            Model.codellama_13b_instruction : "llama2",
            Model.atom_7b : "atom",
            Model.chatglm3_6b : "chatglm3",
            Model.mixtral_8x7B_v01 : "mistral",
            Model.chinese_mixtral_instruct : "mistral",
            Model.llama3_8b_instruct : "llama3",
            Model.llama3_cn_8b_instruct : "llama3",
            Model.chinese_alpaca_2 : "llama2_zh",
            Model.chinese_alpaca_2_13b : "llama2_zh",
            Model.chinese_alpaca_2_7b_16k : "llama2_zh",
            Model.chinese_alpaca_2_13b_16k : "llama2_zh",
            Model.chinese_alpaca_2_1b3 : "llama2_zh",
            Model.phi_3_mini_128k_instruct : "phi",
        }
    return template_dict.get(model_name,"default")